* ***************************************************************** *
* ***************************************************************** *
*   File-Name:      mds.do                                          *
*   Date:           April 11, 2016                                  *
*   Author:         TG                                              *
*   Purpose:      	Analysis of similarity data                     *
*  					Sondervoten Landau						        *
*   Input File:     Values of adj_matrix_landau_weighted.csv        *
*   Output File:    Abbildung 2 und 3 im paper                      *
* ****************************************************************  *
* ****************************************************************  *


* minor fixes to correct data errors in input matrix, Dezember 9, 2016

version 14.2
clear
capture log close
set more off

*************************
** Get similarity data **
*************************

* Define Names of judges for 1st period
global names Bross	Osterloh	DiFabio	Mellinghoff	Lübbe-Wolff	Gerhardt	Landau	Voßkuhle 

*values  of the matrix below are based on adj_matrix_landau_weighted.csv
matrix input Landau1 = ( ///
0.8		0.5		0.6					0.8					0.7					0.5					0.5 			  ///
		0.5		0.4					0.6					0.8					0.3					1                 ///
				0.909090909090909	0.5					0.25				0.666666666666667	0.75  			  ///
									0.545454545454545	0.272727272727273	0.727272727272727	0.333333333333333 ///
														0.529411764705882	0.529411764705882	0.666666666666667 ///
																			0.352941176470588	0.666666666666667 ///
																								0.636363636363636)


																								
* Higher values for protect() will show that we actually reached a global minimum!
mdsmat Landau1, names($names) shape(uupper) s2d(oneminus) meth(modern) init(random(12345)) protect(10) nolog config

* Check diagnostics
estat quantiles
estat correlations
estat pairwise



*************************
** Graph Configuration **
*************************


* Save coordinates into data set
predict d1 d2, config saving(Landau1, replace)

use Landau1, clear


* Deviations indicate lack of fit when regressing (transformed) disimilarities on distance	
* looks resonable										
mdsshepard									
mdsshepard, separat		


replace Category="Broß" if Category=="Bross"
replace Category="Di Fabio" if Category=="DiFabio"

set obs 8
capture drop pos spd dim1 dim2
generate pos = 3
replace pos=9 if Category=="Lübbe-Wolff"

gen spd= (inlist(Category, "Osterloh", "Lübbe-Wolff", "Gerhardt","Voßkuhle"))


ren d1 dim1
gen d1 = -1*dim1 /* MDS is invariant to orthogonal rotation */

ren d2 dim2
gen d2 = -1*dim2 /* MDS is invariant to orthogonal rotation */

#delimit;
twoway scatter  d2 d1 if spd==1,  mlabvpos(pos) 
mcolor(gray) mlabel(Category) mlabcolor(gray) msymbol(Oh)||
 scatter  d2 d1 if spd==0,  mlabvpos(pos) 
mcolor(black) mlabel(Category) mlabcolor(black) msymbol(O)
scheme(s1mono)                                 
    legend(off)                                                                          
    ylabel(-.5(.1).5,  nolabel )    xsize(2.4)
	xlabel(-.5(.1).5,  nolabel )    ysize(2)
	xscale(titlegap(3) nofextend ) 
	yscale(titlegap(3) nofextend )
	xtitle(" ")
	ytitle(" ")        
	graphregion(fcolor(white)) 
	plotregion(lcolor(white))
saving(landau1,replace);
#delimit cr;


*Produced Figure 2 in the Paper
graph export landau1.pdf, replace
graph export landau1.tif, replace
graph export landau1.pdf, replace
graph export landau1.png, replace





*************************
** Get similarity data **
*************************

* Define Names of judges for 2nd period
global names2 Lübbe-Wolff	Gerhardt	Landau	Voßkuhle	Huber	Hermanns Müller	Kessal-Wulf 

*values  below are based on adj_matrix_landau_weighted.csv



matrix input Landau2 = ( ///
	0.529411764705882	0.529411764705882	0.666666666666667	0.571428571428571	0.714285714285714	0.4		0.5  ///
						0.352941176470588	0.666666666666667	0.571428571428571	0.714285714285714	0.6		0.5  ///
											0.636363636363636	0.7					0.8					0.625	1   ///
																0.777777777777778	1		0.857142857142857	0.666666666666667 ///
																					0.7		0.5					0.571428571428571  ///
																					0.875	0.714285714285714 ///
																						0.571428571428571)
																				
																						
* Higher values for protect() will show that we actually reached a global minimum!
mdsmat Landau2, names($names2) shape(uupper) s2d(oneminus) meth(modern) init(random(12345)) protect(10) nolog config

* Check diagnostics
estat quantiles
estat correlations
estat pairwise



*************************
** Graph Configuration **
*************************


* Save coordinates into data set
predict d1 d2, config saving(Landau2, replace)

use Landau2, clear

* Deviations indicate lack of fit when regressing (transformed) disimilarities on distance	
* looks resonable										
mdsshepard									
mdsshepard, separat		


set obs 8
capture drop pos2 dim* spd
generate pos2 = 3
replace pos2 = 11 if Category=="Hermanns"
replace pos2 = 9 if Category=="Voßkuhle"
replace pos2 = 9 if Category=="Gerhardt"
replace pos2 = 9 if Category=="Lübbe-Wolff"
*replace pos2 = 1 if Category=="Landau"

ren d1 dim1
ren d2 dim2

gen d1 = -1*dim1 /* MDS is invariant to orthogonal rotation */
gen d2 = -1*dim2 /* MDS is invariant to orthogonal rotation */


gen spd= (inlist(Category, "Hermanns", "Lübbe-Wolff", "Gerhardt",	"Voßkuhle"))

#delimit;
twoway scatter  d2 d1 if spd==1,  mlabvpos(pos2) 
mcolor(gray) mlabel(Category) mlabcolor(gray) msymbol(Oh) ||
 scatter  d2 d1 if spd==0,  mlabvpos(pos2) 
mcolor(black) mlabel(Category) mlabcolor(black) msymbol(O)
scheme(s1mono)                                 
    legend(off)                                                                          
    ylabel(-.5(.1).5,  nolabel )    
	xlabel(-.5(.1).5,  nolabel )
	xscale(titlegap(3) nofextend ) xsize(2.4)
	yscale(titlegap(3) nofextend ) ysize(2)
	xtitle(" ")
	ytitle(" ")        
	graphregion(fcolor(white)) 
	plotregion(lcolor(white))
saving(landau2,replace);
#delimit cr;

*Produced Figure 3 in the Paper
graph export landau2.pdf, replace
graph export landau2.tif, replace
graph export landau2.pdf, replace
graph export landau2.png, replace

		

